//-----------------------------------------------------------------------------
//    KAmodTFT2 software library
//-----------------------------------------------------------------------------
//
//    THE SOFTWARE INCLUDED IN THIS FILE IS FOR GUIDANCE ONLY.
//    BTC KORPORACJA SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT
//    OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
//    FROM USE OF THIS SOFTWARE.
//
//                     http://www kamami.com
//-----------------------------------------------------------------------------


#include "stm32f10x_lib.h"
#include "lcdlib.h"
#include "board.h"


// I/O port lines control functions

void SetBit(int bits)
{
	GPIO_SetBits(PORT_ctrl, bits);
}

void ClrBit(int bits)
{
	GPIO_ResetBits(PORT_ctrl, bits);
}


// SPI functions

void WriteSpi(unsigned char data)
{
	unsigned char i;
	SetBit(CLK);
    for (i = 0; i < 8; i++) 
	{
		ClrBit(CLK);
        if ((data&0x80))
		 	SetBit(DATA);
		  else 
		 	ClrBit(DATA);
		SetBit(CLK);
        data <<= 1;
    }
	SetBit(CS);
}

void WriteSpiCommand(unsigned char cmd)
{
	ClrBit(CS);
	ClrBit(CLK);
	ClrBit(DATA); // For commands the first bit is 0
	WriteSpi(cmd);
}


void WriteSpiData(unsigned char data)
{
	ClrBit(CS);
	ClrBit(CLK);
	SetBit(DATA); // For data the first bit is 1
	WriteSpi(data);
}



// This function sets contrast. con should be value in range <-64...63>
void SetContrast(char con)
{
	WriteSpiCommand(SETCON);
	WriteSpiData(con);
}

// Initialize display
void InitLcdNokia(void) 
{
	int i;
	// Hardware reset
	SetBit(CS);
	SetBit(CLK);
	SetBit(DATA);
	ClrBit(RES);
	for(i = 0; i < 80000; i++);
	SetBit(RES);
	for(i = 0; i < 80000; i++);

	// Sleep out
	WriteSpiCommand(SLEEPOUT);

	// Inversion on (command 0x20)
	WriteSpiCommand(INVOFF); 

	// Color Interface Pixel Format (command 0x3A)
	WriteSpiCommand(COLMOD);
	WriteSpiData(0x03); // 0x03 = 12 bits-per-pixel

	// Memory access controler (command 0x36)
	WriteSpiCommand(MADCTL);
	WriteSpiData(0x50);

	for(i = 0; i < 2000; i++);

	// Display On (command 0x29)
	WriteSpiCommand(DISPON);	
}


// Set all pixels to color
void LCDClearScreen(unsigned int color) 
{
	int i;
	// Set row address range
	WriteSpiCommand(PASET);
	WriteSpiData(0);
	WriteSpiData(131);

	// Set column address range
	WriteSpiCommand(CASET);
	WriteSpiData(0);
	WriteSpiData(131);

	// Write memory
	WriteSpiCommand(RAMWR);
	for(i = 0; i < (131 * 131); i++) 
	{
		WriteSpiData(color);
		WriteSpiData(color >> 4);
	}
}


// Set x, y pixel to color
void LCDSetPixel(int x, int y, unsigned int color)
{
	// Set columns address range
	WriteSpiCommand(CASET); 
	WriteSpiData(x);
	WriteSpiData(131);
	
	// Set rows address range
	WriteSpiCommand(PASET);
	WriteSpiData(y);
	WriteSpiData(131);

	// Write memory
	WriteSpiCommand(RAMWR);
	WriteSpiData(color);
	WriteSpiData(color >> 4);
}

