//-----------------------------------------------------------------------------
//    KAmodMEMS2 software library
//-----------------------------------------------------------------------------
//
//    THE SOFTWARE INCLUDED IN THIS FILE IS FOR GUIDANCE ONLY.
//    BTC KORPORACJA SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT
//    OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
//    FROM USE OF THIS SOFTWARE.
//
//                     http://www kamami.com
//-----------------------------------------------------------------------------


#include "lis35.h"
#include "board.h"
#include "stm32f10x_lib.h"





/************************* SPI Functions **********************************************/

void SPI_Transmit(char cData)
{ 
    SPI_I2S_SendData(SPI1, cData);

    while (SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_RXNE) == RESET) { ; }

    SPI_I2S_ReceiveData(SPI1);
}


char SPI_Receive(void)
{
    SPI_I2S_SendData(SPI1, 0xFF);

    while (SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_RXNE) == RESET) { ; }

    return SPI_I2S_ReceiveData(SPI1);
}

void SPI_CS_Enable(void)
{
	GPIO_ResetBits(GPIO_CS, GPIO_Pin_CS);
}

void SPI_CS_Disable(void)
{
	GPIO_SetBits(GPIO_CS, GPIO_Pin_CS);
}


/************************* SPI Functions - end *****************************************/





void LIS35_RebootMemory()
{
	SPI_CS_Enable();
	SPI_Transmit(LIS35_WRITE|LIS35_ADDR_NO_INC|LIS35_REG_CR2);
	SPI_Transmit(LIS35_REG_CR2_BOOT);
	SPI_CS_Disable();
}


char InitializeLIS35(void)
{
	char RegVal, LIS35Settings;
  
	//Reset LIS35 configuration
    LIS35_RebootMemory(); 

	LIS35_ReadRegister(LIS35_REG_CR1, &RegVal);

	//Power up
	LIS35Settings = LIS35_REG_CR1_XEN | LIS35_REG_CR1_YEN | LIS35_REG_CR1_ZEN | LIS35_REG_CR1_ACTIVE;
	LIS35_WriteRegister(LIS35_REG_CR1, LIS35Settings);
	LIS35_ReadRegister(LIS35_REG_CR1, &RegVal);

	//Check whether power up is set
	if (RegVal == LIS35Settings) return LIS35_OK;

	return LIS35_ERROR;
}


void LIS35_ReadRegister(char addr,char * v)
{
	SPI_CS_Enable();
	SPI_Transmit(LIS35_READ|LIS35_ADDR_NO_INC|addr);
	*v=SPI_Receive();
	SPI_CS_Disable();
}


void LIS35_WriteRegister(char addr,char v)
{
	SPI_CS_Enable();
	SPI_Transmit(LIS35_WRITE|LIS35_ADDR_NO_INC|addr);
	SPI_Transmit(v);
	SPI_CS_Disable();
}

void LIS35_GetPosition(signed char * x, signed char * y, signed char * z)
{
	SPI_CS_Enable();
	SPI_Transmit(LIS35_READ|LIS35_ADDR_INC|LIS35_REG_OUTX);

	*x=SPI_Receive();
	SPI_Receive();
	*y=SPI_Receive();
	SPI_Receive();
	*z=SPI_Receive();
	SPI_CS_Disable();
}

